<?php
/**
 * A command for the city map
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015, 2016 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class CityHtmlCityMapCommand extends BaseCommand implements Commandable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this command and sets the resolver instance
	 *
	 * @param	$resolverInstance	An instance of a command resolver
	 * @return	$commandInstance	The created command instance
	 */
	public static final function createCityHtmlCityMapCommand (CommandResolver $resolverInstance) {
		// Get a new instance
		$commandInstance = new CityHtmlCityMapCommand();

		// Set the resolver instance
		$commandInstance->setResolverInstance($resolverInstance);

		// Return the prepared instance
		return $commandInstance;
	}

	/**
	 * Executes the command with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// First get a UserRegistration instance
		$managerInstance = ManagerFactory::createManagerByType('city');

		// Make sure the instance is valid
		assert($managerInstance instanceof ManageableCity);

		// First set request and response instance
		$managerInstance->setRequestInstance($requestInstance);
		$managerInstance->setResponseInstance($responseInstance);

		// Is there already a city the user has founded?
		if ($managerInstance->isCityAlreadyFounded()) {
			// Found 2nd,3rd,... city
			$managerInstance->foundNewCity();
		} else {
			// Found first city
			$managerInstance->foundFirstCity();
		}

		// Redirect or login after registration
		$managerInstance->doPostAction();
	}

	/**
	 * Adds extra filters to the given controller instance
	 *
	 * @param	$controllerInstance		A controller instance
	 * @param	$requestInstance		An instance of a class with an Requestable interface
	 * @return	void
	 * @todo	Add some more pre/post filters to the controller
	 */
	public function addExtraFilters (Controller $controllerInstance, Requestable $requestInstance) {
		// Add user auth filter (we don't need an update of the user here because it will be redirected)
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_auth_filter'));

		// Validate user status ('confirmed' no guest)
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_status_filter'));

		// Check if city name is already used
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('city_name_verifier_filter'));

		// Validate ...
		//$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('email_validator_filter'));
	}
}

// [EOF]
?>
