<?php
/**
 * A command for registration handling
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015, 2016 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class CityHtmlRegisterCommand extends BaseCommand implements Commandable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this command and sets the resolver instance
	 *
	 * @param	$resolverInstance	An instance of a command resolver
	 * @return	$commandInstance	The created command instance
	 */
	public static final function createCityHtmlRegisterCommand (CommandResolver $resolverInstance) {
		// Get a new instance
		$commandInstance = new CityHtmlRegisterCommand();

		// Set the resolver instance
		$commandInstance->setResolverInstance($resolverInstance);

		// Return the prepared instance
		return $commandInstance;
	}

	/**
	 * Executes the command with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		/*
		 * This is a generic HTML request, this means that a regular page with
		 * header, menu, content and footer shall be send to the client.
		 */
		$this->sendGenericGetResponse($requestInstance, $responseInstance, '_form');
	}

	/**
	 * Adds extra filters to the given controller instance
	 *
	 * @param	$controllerInstance		A controller instance
	 * @param	$requestInstance		An instance of a class with an Requestable interface
	 * @return	void
	 * @todo	Add some more pre/post filters to the controller
	 */
	public function addExtraFilters (Controller $controllerInstance, Requestable $requestInstance) {
	}
}

// [EOF]
?>
