<?php
/**
 * The default controller for logout page
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015, 2016 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 * @todo		This controller shall still provide some headlines for sidebars
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class CityHtmlLogoutController extends BaseController implements Controller {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Init additional filter chains
		foreach (array('shutdown') as $filterChain) {
			$this->initFilterChain($filterChain);
		} // END - foreach
	}

	/**
	 * Creates an instance of this class
	 *
	 * @param	$resolverInstance		An instance of a command resolver class
	 * @return	$controllerInstance		A prepared instance of this class
	 */
	public static final function createCityHtmlLogoutController (CommandResolver $resolverInstance) {
		// Create the instance
		$controllerInstance = new CityHtmlLogoutController();

		// Set the command resolver
		$controllerInstance->setResolverInstance($resolverInstance);

		// Add user auth filter (we don't need an update of the user here because it will be redirected)
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_auth_filter'));

		// User status filter
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_status_filter'));

		// Return the prepared instance
		return $controllerInstance;
	}

	/**
	 * Handles the given request and response
	 *
	 * @param	$requestInstance	An instance of a request class
	 * @param	$responseInstance	An instance of a response class
	 * @return	void
	 */
	public function handleRequest (Requestable $requestInstance, Responseable $responseInstance) {
		// Get the command instance
		$commandInstance = $this->getResolverInstance()->resolveCommandByRequest($requestInstance);

		// This request was valid! :-D
		$requestInstance->requestIsValid();

		// Execute the command
		$commandInstance->execute($requestInstance, $responseInstance);

		// Flush the response out
		$responseInstance->flushBuffer();
	}
}

// [EOF]
?>
