<?php
/**
 * A city sections manager
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015, 2016 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class CitySectionsManager extends BaseFrameworkSystem implements ManageableCitySections, Registerable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$managerInstance	An instance of a ManageableCitySections class
	 */
	public final static function createCitySectionsManager () {
		// Get new instance
		$managerInstance = new CitySectionsManager();

		// Get database wrapper
		$wrapperInstance = DatabaseWrapperFactory::createWrapperByConfiguredName('city_sections_db_wrapper_class');

		// And set it here
		$managerInstance->setWrapperInstance($wrapperInstance);

		// Return the prepared instance
		return $managerInstance;
	}

	/**
	 * Checks whether at least one map requires expansion
	 *
	 * @return	$requiresExpansion	Whether a map requires expansion
	 * @todo	0% done
	 */
	public function isMapPendingExpansion () {
		// Default is no expansion is needed
		$requireExpansion = FALSE;

		// First, a simple check if the sections table contains any entries at all
		if ($this->getWrapperInstance()->countTotalRows() == 0) {
			// This definedly requires expansion
			$requireExpansion = TRUE;
		} // END - if

		// Return status
		return $requireExpansion;
	}

	/**
	 * Expands any map that requires expansion
	 *
	 * @return	void
	 * @todo ~10% done
	 * @todo z-coordinate not used
	 */
	public function expandMaps () {
		// Get a city info wrapper instance
		$cityWrapperInstance = DatabaseWrapperFactory::createWrapperByConfiguredName('city_info_db_wrapper_class');

		// Get all city ids from it
		$cityIds = $cityWrapperInstance->getAllCityIds();

		// Now check all ids
		foreach ($cityIds as $cityId) {
			// Does this id have any sections
			if (!$this->getWrapperInstance()->ifCityHasSections($cityId)) {
				// Nothing found, so it is a brand-new city that needs first initialization
				$sections = $this->getWrapperInstance()->doInitialCityExpansion($cityId);
			} else {
				// @TODO Maybe some expansion is needed
			}
		} // END - foreach
	}
}

// [EOF]
?>
