<?php
/**
 * A resolver for resolving controllers locally
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015, 2016 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class CityConsoleControllerResolver extends BaseControllerResolver implements ControllerResolver {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set prefix to 'city_console'
		$this->setClassPrefix('city_console');
	}

	/**
	 * Creates an instance of a resolver class with a given controller
	 *
	 * @param	$controllerName				The controller we shall resolve
	 * @param	$applicationInstance		An instance of a manageable application helper class
	 * @return	$resolverInstance			The prepared controller resolver instance
	 * @throws	EmptyVariableException		Thrown if default controller is not set
	 * @throws	InvalidControllerException	Thrown if default controller is invalid
	 */
	public static final function createCityConsoleControllerResolver ($controllerName, ManageableApplication $applicationInstance) {
		// Create the new instance
		$resolverInstance = new CityConsoleControllerResolver();

		// Is the variable $controllerName set and the controller is valid?
		if (empty($controllerName)) {
			// Then thrown an exception here
			throw new EmptyVariableException(array($resolverInstance, 'controllerName'), self::EXCEPTION_UNEXPECTED_EMPTY_STRING);
		} elseif ($resolverInstance->isControllerValid($controllerName) === FALSE) {
			// Invalid controller found
			throw new InvalidControllerException(array($resolverInstance, $controllerName), self::EXCEPTION_INVALID_CONTROLLER);
		}

		// Set the application instance
		$resolverInstance->setApplicationInstance($applicationInstance);

		// Set controller name
		$resolverInstance->setControllerName($controllerName);

		// Return the prepared instance
		return $resolverInstance;
	}
}

// [EOF]
?>
